summaryrefslogtreecommitdiffstats
path: root/adf/libadf/include
diff options
context:
space:
mode:
authorGreg Hackmann <ghackmann@google.com>2013-11-12 10:38:36 -0800
committerGreg Hackmann <ghackmann@google.com>2013-11-26 15:40:02 -0800
commit47e0c8d849277a4b96fc364e5703f301e2b94519 (patch)
tree9194cbaf4f28b3eb89854422559d8d102affaf38 /adf/libadf/include
parentebb26c71fe59c1904dc198b00948c581d31bd412 (diff)
downloadsystem_core-47e0c8d849277a4b96fc364e5703f301e2b94519.zip
system_core-47e0c8d849277a4b96fc364e5703f301e2b94519.tar.gz
system_core-47e0c8d849277a4b96fc364e5703f301e2b94519.tar.bz2
libadf: filter overlay engines by a list of acceptable formats
Change-Id: Ibb294f0520a7a7a6a2a89e1e3eb3c335906d3e66 Signed-off-by: Greg Hackmann <ghackmann@google.com>
Diffstat (limited to 'adf/libadf/include')
-rw-r--r--adf/libadf/include/adf/adf.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/adf/libadf/include/adf/adf.h b/adf/libadf/include/adf/adf.h
index 5d301f3..8ce994f 100644
--- a/adf/libadf/include/adf/adf.h
+++ b/adf/libadf/include/adf/adf.h
@@ -182,10 +182,12 @@ ssize_t adf_overlay_engines_for_interface(struct adf_device *dev,
/**
* Filters a list of overlay engines by supported buffer format.
*
* The caller must free() the returned list of overlay engine IDs.
*/
ssize_t adf_overlay_engines_filter_by_format(struct adf_device *dev,
- __u32 format, adf_id_t *in, size_t n_in, adf_id_t **out);
+ const __u32 *formats, size_t n_formats, adf_id_t *in, size_t n_in,
+ adf_id_t **out);
/**
* Opens an ADF overlay engine.
@@ -182,10 +182,12 @@ ssize_t adf_overlay_engines_for_interface(struct adf_device *dev,
* Filters a list of overlay engines by supported buffer format.
*
- * The caller must free() the returned list of overlay engine IDs.
+ * Returns the overlay engines which support at least one of the specified
+ * formats. The caller must free() the returned list of overlay engine IDs.
*/
ssize_t adf_overlay_engines_filter_by_format(struct adf_device *dev,